@@ -71,6 +71,42 @@ class CoreUser(models.Model):
         return u", ".join(field for field in fields
                           if field and field.strip())
 
+class CoreList(models.Model):
+    id = models.IntegerField(primary_key=True)
+    created_at = models.DateTimeField()
+    updated_at = models.DateTimeField()
+    hidden = models.BooleanField()
+    name = models.CharField(max_length=255)
+    notes = models.CharField(max_length=255, null=True, blank=True)
+    is_default = models.BooleanField()
+
+    class Meta:
+        db_table = u'core_list'
+        managed = False    
+    
+class CoreSubscription(models.Model):
+    id = models.IntegerField(primary_key=True)
+    created_at = models.DateTimeField()
+    updated_at = models.DateTimeField()
+    user = models.ForeignKey(CoreUser)
+    list = models.ForeignKey(CoreList)
+    
+    class Meta:
+        db_table = u'core_subscription'
+        managed = False
+
+class CoreSubscriptionHistory(models.Model):
+    id = models.IntegerField(primary_key=True)
+    created_at = models.DateTimeField()
+    updated_at = models.DateTimeField()
+    user = models.ForeignKey(CoreUser)
+    list = models.ForeignKey(CoreList)
+    change_id = models.IntegerField()
+    
+    class Meta:
+        db_table = u'core_subscriptionhistory'
+        managed = False
+
 class CoreUserField(models.Model):
     parent = models.ForeignKey(CoreUser, related_name='fields')
     name = models.TextField()
@@ -119,12 +155,23 @@ class CorePage(models.Model):
     goal = models.IntegerField(null=True, blank=True)
     goal_type = models.CharField(max_length=765)
     status = models.CharField(max_length=765)
-    #list = models.ForeignKey(CoreList)
+    list = models.ForeignKey(CoreList)
     hidden = models.IntegerField()
+    allow_multiple_responses = models.BooleanField()
+    
     class Meta:
         db_table = u'core_page'
         managed = False
 
+class CorePageField(models.Model):
+    parent = models.ForeignKey(CorePage, related_name='fields')
+    name = models.TextField()
+    value = models.TextField()
+    class Meta:
+        db_table = 'core_pagefield'
+        managed = False
+
+
 class CoreAction(models.Model):
     id = models.IntegerField(primary_key=True)
     created_at = models.DateTimeField()
@@ -177,6 +224,7 @@ class CoreOrder(models.Model):
     total = models.FloatField()
     status = models.CharField(max_length=255)
     import_id = models.CharField(max_length=32, null=True)
+    card_num_last_four = models.CharField(max_length=32, null=True)
     class Meta:
         db_table = u'core_order'
         managed = False
@@ -360,6 +408,29 @@ class Event(models.Model):
         db_table = "events_event"
         managed = False
 
+class Eventfield(models.Model):
+    parent = models.ForeignKey(Event, related_name='fields')
+    name = models.TextField()
+    value = models.TextField()
+    class Meta:
+        db_table = 'events_eventfield'
+        managed = False
+
+class EventSignup(models.Model):
+    id = models.IntegerField(primary_key=True)
+    created_at = models.DateTimeField()
+    updated_at = models.DateTimeField()
+    user = models.ForeignKey(CoreUser)
+    event = models.ForeignKey(Event)
+    role = models.CharField(max_length=255)
+    status = models.CharField(max_length=255)
+    page = models.ForeignKey(CorePage)
+    attended = models.BooleanField(default=False)
+
+    class Meta:
+        db_table = "events_eventsignup"
+        managed = False
+
 
 class CmsPetitionForm(models.Model):
     id = models.IntegerField(primary_key=True)
@@ -390,7 +461,10 @@ class CorePageFollowup(models.Model):
         managed = False
 
 from django.db import connections
-from django.utils.datastructures import SortedDict
+try:
+    from django.utils.datastructures import SortedDict
+except ImportError:
+    from collections import OrderedDict as SortedDict
 
 def dictfetchall(cursor):
     "Returns all rows from a cursor as a dict"
