@@ -1,5 +1,19 @@
-from actionkit.models import QueryReport
-from django.conf import settings
+try:
+    from actionkit.models import QueryReport
+    from django.conf import settings
+except ImportError:
+    import os
+    QueryReport = None
+    NULL = object()
+    class Settings(object):
+        def __getattr__(self, attr, default=NULL):
+            try:
+                return os.environ[attr]
+            except KeyError:
+                if default is NULL:
+                    raise AttributeError
+                else:
+                    return default
 import json
 import requests
 from requests.auth import HTTPBasicAuth
@@ -33,7 +47,7 @@ class client(object):
 
     def __getattr__(self, attr):
         if not self.safety_net:
-            return ClientResourceHandler(attr, object_methods=["get", "put", "delete"],
+            return ClientResourceHandler(attr, object_methods=["get", "put", "delete", "patch"],
                                          collection_methods=["get", "post"])
             
         url = self.base_url + attr + "/schema/"
@@ -96,6 +110,13 @@ class ClientResourceHandler(object):
     def exists(self, id):
         return self._get(id)
 
+    def patch(self, id, **kw):
+        self.check_method("patch")
+        resp = request(self.base_url + "%s/" % id, "patch", 
+                       headers={'content-type': 'application/json'},
+                       data=json.dumps(kw))
+        assert resp.status_code == 202, (resp, resp.text)
+    
     def put(self, id, **kw):
         self.check_method("put")
         resp = request(self.base_url + "%s/" % id, "put", 
@@ -164,6 +185,9 @@ def unhide_report(report_id):
     if not host.startswith("https"):
         host = "https://" + host
 
+    if QueryReport is None:
+        raise RuntimeError("this function requires Django for some reason.")
+    
     report = QueryReport.objects.using("ak").select_related("report_ptr").get(
         report_ptr__id=report_id)
     data = json.dumps(dict(hidden=False, 
